@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.733';
+our $VERSION = '1.734';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -49,6 +49,44 @@ sub new {
 }
 
 
+sub _valid_options {
+    return {
+        beep                => '[ 0 1 ]',
+        clear_screen        => '[ 0 1 ]',
+        codepage_mapping    => '[ 0 1 ]',
+        hide_cursor         => '[ 0 1 ]',
+        index               => '[ 0 1 ]',
+        mouse               => '[ 0 1 ]',
+        order               => '[ 0 1 ]',
+        alignment           => '[ 0 1 2 ]',
+        color               => '[ 0 1 2 ]',
+        f3                  => '[ 0 1 2 ]',
+        include_highlighted => '[ 0 1 2 ]',
+        page                => '[ 0 1 2 ]',
+        layout              => '[ 0 1 2 3 ]',
+        keep                => '[ 1-9 ][ 0-9 ]*', ## 0 ?
+        ll                  => '[ 1-9 ][ 0-9 ]*',
+        max_cols            => '[ 1-9 ][ 0-9 ]*',
+        max_height          => '[ 1-9 ][ 0-9 ]*',
+        max_width           => '[ 1-9 ][ 0-9 ]*',
+        default             => '[ 0-9 ]+',
+        pad                 => '[ 0-9 ]+',
+        mark                => 'Array_Int',
+        meta_items          => 'Array_Int',
+        no_spacebar         => 'Array_Int',
+        tabs_info           => 'Array_Int',
+        tabs_prompt         => 'Array_Int',
+        skip_items          => 'Regexp', # experimental
+        empty               => 'Str',
+        footer              => 'Str',
+        info                => 'Str',
+        prompt              => 'Str',
+        undef               => 'Str',
+        busy_string         => 'Str',
+    };
+};
+
+
 sub _defaults {
     return {
         alignment           => 0,
@@ -87,44 +125,6 @@ sub _defaults {
 }
 
 
-sub _valid_options {
-    return {
-        beep                => '[ 0 1 ]',
-        clear_screen        => '[ 0 1 ]',
-        codepage_mapping    => '[ 0 1 ]',
-        hide_cursor         => '[ 0 1 ]',
-        index               => '[ 0 1 ]',
-        mouse               => '[ 0 1 ]',
-        order               => '[ 0 1 ]',
-        alignment           => '[ 0 1 2 ]',
-        color               => '[ 0 1 2 ]',
-        f3                  => '[ 0 1 2 ]',
-        include_highlighted => '[ 0 1 2 ]',
-        page                => '[ 0 1 2 ]',
-        layout              => '[ 0 1 2 3 ]',
-        keep                => '[ 1-9 ][ 0-9 ]*',
-        ll                  => '[ 1-9 ][ 0-9 ]*',
-        max_cols            => '[ 1-9 ][ 0-9 ]*',
-        max_height          => '[ 1-9 ][ 0-9 ]*',
-        max_width           => '[ 1-9 ][ 0-9 ]*',
-        default             => '[ 0-9 ]+',
-        pad                 => '[ 0-9 ]+',
-        mark                => 'Array_Int',
-        meta_items          => 'Array_Int',
-        no_spacebar         => 'Array_Int',
-        tabs_info           => 'Array_Int',
-        tabs_prompt         => 'Array_Int',
-        skip_items          => 'Regexp', # experimental
-        empty               => 'Str',
-        footer              => 'Str',
-        info                => 'Str',
-        prompt              => 'Str',
-        undef               => 'Str',
-        busy_string         => 'Str',
-    };
-};
-
-
 sub __copy_orig_list {
     my ( $self, $orig_list_ref ) = @_;
     if ( $self->{ll} ) {
@@ -231,13 +231,16 @@ sub __get_key {
 
 sub __modify_options {
     my ( $self ) = @_;
+    if ( defined $self->{max_cols} && $self->{max_cols} == 1 ) {
+        $self->{layout} = 3;
+    }
     if ( length $self->{footer} && $self->{page} != 2 ) {
         $self->{page} = 2;
     }
     if ( $self->{page} == 2 && ! $self->{clear_screen} ) {
         $self->{clear_screen} = 1;
     }
-    if ( $self->{max_cols} && $self->{layout} != 0 && $self->{layout} != 3 ) {
+    if ( $self->{max_cols} && $self->{layout} != 0 && $self->{layout} != 3 ) { ##
         $self->{layout} = 0;
     }
     if ( ! defined $self->{prompt} ) {
@@ -1199,7 +1202,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.733
+Version 1.734
 
 =cut
 
