@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.733';
+our $VERSION = '1.734';
 
 use Exporter qw( import );
 
@@ -99,9 +99,6 @@ sub line_fold {
     if ( ! defined $str || ! length $str ) {
         return $str;
     }
-    if ( $^O ne 'MSWin32' && $^O ne 'cygwin' ) {
-        $avail_width += WIDTH_CURSOR;
-    }
     for ( $opt->{init_tab}, $opt->{subseq_tab} ) {
         if ( defined $_ && length $_ ) {
             s/\t/ /g;
